# frozen_string_literal: true

#
# Author:: Jonathan Hartman (<jonathan.hartman@socrata.com>)
#
# Copyright (C) 2018, Socrata, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

module Kitchen
  module Microwave
    # The suites config can be generated by examining the `test` wrapper
    # cookbook.
    #
    # @author Jonathan Hartman <jonathan.hartman@socrata.com>
    class Suites < Array
      #
      # Examine the cookbook's test harness and consider any public (i.e. not
      # named with a leading "_") recipe to be a test suite.
      #
      # @param [String] cookbook_dir path to the cookbook under test
      #
      # @return [Kitchen::Microwave::Suites] the new suites object
      #
      def initialize(cookbook_dir)
        glob = File.join(cookbook_dir,
                         'test/fixtures/cookbooks/test/recipes/[a-z0-9]*.rb')
        Dir.glob(glob).sort.each do |ste|
          self << {
            'name' => File.basename(ste, '.rb'),
            'run_list' => %W[recipe[test::#{File.basename(ste, '.rb')}]]
          }
        end
      end
    end
  end
end
