# frozen_string_literal: true

#
# Author:: Jonathan Hartman (<jonathan.hartman@socrata.com>)
#
# Copyright (C) 2018, Socrata, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

require 'kitchen/cli'
require_relative 'loader/microwave'

module Kitchen
  # A wrapper CLI that does everything the same as Kitchen except uses
  # Microwave's custom config loader.
  #
  # @author Jonathan Hartman <jonathan.hartman@socrata.com>
  class MicrowaveCLI < Kitchen::CLI
    #
    # Copy-pasta from Test Kitchen's CLI with a replacement loader class.
    #
    # (see Kitchen::CLI.initialize)
    #
    def initialize(*args)
      super
      @loader = Kitchen::Loader::Microwave.new(
        project_config: ENV['KITCHEN_YAML'] || ENV['KITCHEN_YML'],
        local_config: ENV['KITCHEN_LOCAL_YAML'] || ENV['KITCHEN_LOCAL_YML'],
        global_config: ENV['KITCHEN_GLOBAL_YAML'] || ENV['KITCHEN_GLOBAL_YML']
      )
      @config = Kitchen::Config.new(loader: @loader,
                                    log_level: Kitchen.env_log,
                                    log_overwrite: Kitchen.env_log_overwrite)
    end
  end
end
